# Settings specified here will take precedence over those in config/environment.rb

# In the development environment your application's code is reloaded on
# every request.  This slows down response time but is perfect for development
# since you don't have to restart the webserver when you make code changes.
config.cache_classes     = false 

# Log error messages when you accidentally call methods on nil.
config.whiny_nils        = true

# Show full error reports and disable caching
config.action_controller.consider_all_requests_local = true
config.action_controller.perform_caching             = false

# Don't care if the mailer can't send
config.action_mailer.raise_delivery_errors = false

# for the graphs plugin
config.cache_classes     = true
config.action_controller.perform_caching             = true

# AnnoTrack-specific settings
REGISTRY = {}
REGISTRY['browser_ensembl_region'] = 'Homo_sapiens'
REGISTRY['browser_ensembl_transcript'] = 1
REGISTRY['browser_ensembl_add'] = 0
REGISTRY['browser_ucsc'] = 1
REGISTRY['browser_ncbi'] = 1
REGISTRY['browser_zfin'] = 0
REGISTRY['browser_vega_region'] = 'Homo_sapiens'
REGISTRY['browser_vega_transcript'] = 1
REGISTRY['browser_vega_add'] = 0
REGISTRY['browser_congo'] = 1
REGISTRY['organism'] = 'Human'
